/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using System;
using System.IO;

class Dateien
{
	public static bool aAktualisieren(string strFileName, 
	                                 string strPathSource, 
	                                 string strPathDestination)
	{
		if (!File.Exists(strPathDestination + strFileName))
		{
			return Kopieren(strFileName, strPathSource, strPathDestination);
		}
		DateTime dateTimeOriginal;
		try
		{
			dateTimeOriginal = File.GetLastWriteTime(strPathSource + strFileName);
		}
		catch
		{
			// Message // todo:
				Console.WriteLine("Die Datei " + strPathSource + strFileName + " kann nicht geöffnet werden.");
			return false;
		}
		DateTime dateTimeKopie = File.GetLastWriteTime(strPathDestination + strFileName);
		if (dateTimeOriginal > dateTimeKopie)
		{
			try
			{
				File.Delete(strPathDestination + strFileName);
			}
			catch
			{
				// Message // todo:
				Console.WriteLine("Die alte Datei " + strPathDestination + strFileName + " kann nicht gelöscht werden.");
				return false;
			}
			return Kopieren(strFileName, strPathSource, strPathDestination);
		}
		return true;
	}
	
	public static bool Kopieren(string strFileName, 
	                            string strPathSource, 
	                            string strPathDestination)
	{
		try
		{
			File.Copy(strPathSource + strFileName, strPathDestination + strFileName);
			return true;
		}
		catch
		{
			// Message // todo:
				Console.WriteLine("Die Datei " + strPathSource + strFileName + " kann nicht in das Verzeichnis " + strPathDestination + " kopiert werden.");
			return false;
		}
	}
	
	public static bool DirectoryCopy(string strSource,
	                                 string strDest)
	{
		string strSourcePath = Path.GetDirectoryName(strSource);
		string strSourceFolder = Path.GetFileName(strSource);
		string strDestinationPath = Path.GetDirectoryName(strDest);
		return DirectoryCopy(strSourcePath, strSourceFolder, strDestinationPath);
	}
	
	public static bool DirectoryCopy(string strSourcePath,
	                                 string strSourceFolder, 
	                                 string strDestinationPath)
	{
		return DirectoryCopy(true, DateTime.MinValue, strSourcePath, strSourceFolder, strDestinationPath);
	}
	
	public static bool DirectoryCopy(bool bCopyAllFiles,
	                                 DateTime dateTimeCopyFilesWrittenAfter,
	                                 string strSourcePath,
	                                 string strSourceFolder, 
	                                 string strDestinationPath)
	{
		string strSource = strSourcePath + Path.DirectorySeparatorChar + strSourceFolder;
		if (!Directory.Exists(strSource))
		{
			// Message // todo:
				Console.WriteLine("Das Verzeichnis " + strSource + " existiert nicht.");
			return false;
		}
		string strDest = strDestinationPath + Path.DirectorySeparatorChar 
					   + strSourceFolder + Path.DirectorySeparatorChar;
		try { Directory.CreateDirectory(strDest); }
		catch (Exception e)
		{
			Console.WriteLine(e.Message);
			return false;
		}
		string[] astrFiles = Directory.GetFiles(strSource);
		foreach (string str in astrFiles)
		{
			bool bCopy = true;
			if (!bCopyAllFiles)
			{
				DateTime dateTimeLastWrite = File.GetLastWriteTime(str);
				if (dateTimeLastWrite < dateTimeCopyFilesWrittenAfter)
				{
					bCopy = false;
				}
			}
			if (bCopy) 
			{
				try
				{
					File.Copy(str, strDest + Path.GetFileName(str));
				}
				catch (System.IO.FileNotFoundException e)
				{
					// Message // todo:
					Console.WriteLine("Die Datei '" + str + "' konnte nicht kopiert werden.\n\nDetails:\n\n"
					                + e.Message, "Fehler");
					return false;
				}
				
			}
		}
		string[] astrDirectories = Directory.GetDirectories(strSource);
		foreach (string str in astrDirectories)
		{
			string[] astr = str.Split('\\');
			DirectoryCopy(bCopyAllFiles, dateTimeCopyFilesWrittenAfter, strSource, astr[astr.Length - 1], strDest);
		}
		return true;
	}
	
	public static void DirectoryDelete(string strPath)
	{
		if (!Directory.Exists(strPath))
	    {
	    	// Message // todo:
				Console.WriteLine("Der Ordner " + strPath + " konnte nicht gefunden werden.", "Fehler");
	    	return;
	    }
		string[] astr = Directory.GetDirectories(strPath);
		foreach (string str in astr)
		{
			DirectoryDelete(str);
		}
		astr = Directory.GetFiles(strPath);
		foreach (string str in astr)
		{
			try
			{
				File.SetAttributes(str, FileAttributes.Normal);
				File.Delete(str);
			}
			catch (Exception e)
			{
				// Message // todo:
				Console.WriteLine(e.Message);
			}
		}
		try
		{
			File.SetAttributes(strPath, FileAttributes.Normal);
			Directory.Delete(strPath);
		}
		catch (Exception e)
		{
			// Message // todo:
				Console.WriteLine(e.Message);
		}
	}
}
