/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using System;
using System.IO;

class LeerImage
{
	Explorer explorer1;
	Explorer explorer2;
    string strMainFolder;
    
	public LeerImage(Explorer explorer1, Explorer explorer2)
    {
		this.explorer1 = explorer1;
		this.explorer2 = explorer2;
		
		MainForm.mf.cw();
		if (!CreateMainFolder()) return;
		if (!Copy()) return;
		MainForm.mf.cc();
		MainForm.mf.Message("Leeres Image von " + explorer1.Folder
		                + " erfolgreich nach " + explorer2.Folder
		                + Path.DirectorySeparatorChar + strMainFolder
		                + " erstellt.");
    }
	
	bool Copy()
	{
		foreach (CheckButton checkBox in explorer1.aCheckButton)
		{
			if (checkBox.Active)
			{
				if (! DirectoryCopy(
						explorer1.Folder 
							+ Path.DirectorySeparatorChar,
					    checkBox.Label,
					    explorer2.Folder 
					    	+ Path.DirectorySeparatorChar
					    	+ strMainFolder) )
				{
					return false;
				}
			}
		}
		return true;
	}
	
	bool DirectoryCopy(string strSourcePath,
                       string strSourceFolder, 
                       string strDestinationPath)
	{
		string strSource = strSourcePath + Path.DirectorySeparatorChar + strSourceFolder;
		if (!Directory.Exists(strSource))
		{
			MainForm.mf.Message(MessageType.Warning, "Das Verzeichnis " + strSource + " existiert nicht.");
			return false;
		}
		string strDest = strDestinationPath + Path.DirectorySeparatorChar
			+ strSourceFolder + Path.DirectorySeparatorChar;
		Directory.CreateDirectory(strDest);
		string[] astrFiles = Directory.GetFiles(strSource);
		foreach (string str in astrFiles)
		{
			File.Create(strDest + Path.GetFileNameWithoutExtension(str) + Path.GetExtension(str));
		}
		string[] astrDirectories = Directory.GetDirectories(strSource);
		foreach (string str in astrDirectories)
		{
			string[] astr = str.Split(Path.DirectorySeparatorChar);
			DirectoryCopy(strSource, astr[astr.Length - 1], strDest);
		}
		return true;
	}
	
    bool CreateMainFolder()
    {
    	DateTime dt = DateTime.Now;
		strMainFolder = 
			"Leeres Image " + explorer1.Folder.Substring(0, 1) + " " 
			+ dt.Year + "-" + Zweistellig(dt.Month) + "-" + Zweistellig(dt.Day)
			+ " (" + Zweistellig(dt.Hour) + "." + Zweistellig(dt.Minute) 
			+ "." + Zweistellig(dt.Second) + "_" + dt.Millisecond +")";
		try
		{
			Directory.CreateDirectory(explorer2.Folder + Path.DirectorySeparatorChar + strMainFolder);
			return true;
		}
		catch (Exception e)
		{
			MainForm.mf.Message(MessageType.Error, e.Message);
			return false;
		}
    }
    
    string Zweistellig(int i)
    {
    	string str = i.ToString();
    	if (str.Length == 1) str = "0" + str;
    	return str;
    }
}

