/* Copyright (C) 2002-NOW Mischa Lrken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using System;

class Peculiars // http://de.selfhtml.org/html/referenz/zeichen.htm
{
	// [0]	Zeichen 	
	// [1]	Name in HTML 	
	// [2]	Unicode in HTML 	
	// [3]	Beschreibung
	
	// international
	// Benannte Zeichen für den Zeichensatz ISO 8859-1 (SelfHTML)
	internal static string[][] iso = new string[][]
	{
		new string[]{"", "&Auml;"}, // &#196; A Umlaut 	
		new string[]{"", "&Ouml;"}, // &#214; O Umlaut 	
		new string[]{"", "&Uuml;"}, // &#220; U Umlaut 
		
		new string[]{"", "&auml;"}, // &#228; a Umlaut 	
		new string[]{"", "&ouml;"}, // &#246; o Umlaut 	
		new string[]{"", "&uuml;"}, // &#252; u Umlaut 	
		
		new string[]{"", "&szlig;"}, // &#223; scharfes S
		
		new string[]{"", "&Aacute;"}, // &#193; A mit Accent acute 	
		new string[]{"", "&Eacute;"}, // &#201; E mit Accent acute 	
		new string[]{"", "&Iacute;"}, // &#205; I mit Accent acute 	
		new string[]{"", "&Oacute;"}, // &#211; O mit Accent acute 	
		new string[]{"", "&Uacute;"}, // &#218; U mit Accent acute 	
		
		new string[]{"", "&aacute;"}, // &#225; a mit Accent acute 	
		new string[]{"", "&eacute;"}, // &#233; e mit Accent acute 	
		new string[]{"", "&iacute;"}, // &#237; i mit Accent acute 	
		new string[]{"", "&oacute;"}, // &#243; o mit Accent acute 	
		new string[]{"", "&uacute;"}, // &#250; u mit Accent acute 	
		
		new string[]{"", "&Agrave;"}, // &#192; A mit Accent grave
		new string[]{"", "&Egrave;"}, // &#200; E mit Accent grave 	
		new string[]{"", "&Igrave;"}, // &#204; I mit Accent grave 	
		new string[]{"", "&Ograve;"}, // &#210; O mit Accent grave 	
		new string[]{"", "&Ugrave;"}, // &#217; U mit Accent grave 
		
		new string[]{"", "&agrave;"}, // &#224; a mit Accent grave
		new string[]{"", "&egrave;"}, // &#232; e mit Accent grave 	
		new string[]{"", "&igrave;"}, // &#236; i mit Accent grave 	
		new string[]{"", "&ograve;"}, // &#242; o mit Accent grave 	
		new string[]{"", "&ugrave;"}, // &#249; u mit Accent grave 	
		
		/*
		// new string[]{" ", "&nbsp;"},	// &#160; 	Erzwungenes Leerzeichen
		new string[]{"¡", "&iexcl;"}, 	// &#161; 	umgekehrtes Ausrufezeichen
		new string[]{"¢", "&cent;"}, 	// &#162;	Cent-Zeichen
		new string[]{"£", "&pound;"}, 	// &#163; 	Pfund-Zeichen
		new string[]{"¤", "&curren;"},	// &#164; 	Währungszeichen
		new string[]{"¥", "&yen;"}, 	// &#165; 	Yen-Zeichen
		new string[]{"¦", "&brvbar;"}, 	// &#166; 	durchbrochener Strich
		new string[]{"§", "&sect;"},	// &#167; 	Paragraph-Zeichen
		new string[]{"¨", "&uml;"}, 	// &#168; 	Pünktchen oben
		new string[]{"©", "&copy;"},	// &#169; 	Copyright-Zeichen
		new string[]{"ª", "&ordf;"},	// &#170; 	Ordinal-Zeichen weiblich
		new string[]{"«", "&laquo;"}, 	// &#171; 	angewinkelte Anführungszeichen links
		new string[]{"¬", "&not;"}, 	// &#172; 	Verneinungs-Zeichen
		new string[]{"­", "&shy;"}, 	// &#173; 	bedingter Trennstrich
		new string[]{"®", "&reg;"}, 	// &#174; 	Registriermarke-Zeichen
		new string[]{"¯", "&macr;"},	// &#175; 	Überstrich
		new string[]{"°", "&deg;"}, 	// &#176; 	Grad-Zeichen
		new string[]{"±", "&plusmn;"},	// &#177; 	Plusminus-Zeichen
		new string[]{"²", "&sup2;"}, 	// &#178; 	Hoch-2-Zeichen
		new string[]{"³", "&sup3;"}, 	// &#179; 	Hoch-3-Zeichen
		new string[]{"´", "&acute;"}, 	// &#180; 	Acute-Zeichen
		new string[]{"µ", "&micro;"}, 	// &#181; 	Mikro-Zeichen
		new string[]{"¶", "&para;"}, 	// &#182; 	Absatz-Zeichen
		new string[]{"·", "&middot;"},	// &#183; 	Mittelpunkt
		new string[]{"¸", "&cedil;"}, 	// &#184; 	Häkchen unten
		new string[]{"¹", "&sup1;"}, 	// &#185; 	Hoch-1-Zeichen
		new string[]{"º", "&ordm;"}, 	// &#186; 	Ordinal-Zeichen männlich
		new string[]{"»", "&raquo;"}, 	// &#187; 	angewinkelte Anführungszeichen rechts 	
		new string[]{"¼", "&frac14;"},	// &#188; 	ein Viertel 	
		new string[]{"½", "&frac12;"}, 	// &#189; 	ein Halb 	
		new string[]{"¾", "&frac34;"}, 	// &#190; 	drei Viertel 	
		new string[]{"¿", "&iquest;"}, 	// &#191; 	umgekehrtes Fragezeichen 	
		new string[]{"Â", "&Acirc;"}, 	// &#194; 	A mit Circumflex 	
		new string[]{"Ã", "&Atilde;"}, 	// &#195; 	A mit Tilde 	
		new string[]{"Å", "&Aring;"}, 	// &#197; 	A mit Ring 	
		new string[]{"Æ", "&AElig;"}, 	// &#198; 	A mit legiertem E 	
		new string[]{"Ç", "&Ccedil;"}, 	// &#199; 	C mit Häkchen 	
		new string[]{"Ê", "&Ecirc;"}, 	// &#202; 	E mit Circumflex 	
		new string[]{"Ë", "&Euml;"}, 	// &#203; 	E Umlaut 	
		new string[]{"Î", "&Icirc;"}, 	// &#206; 	I mit Circumflex 	
		new string[]{"Ï", "&Iuml;"}, 	// &#207; 	I Umlaut 	
		new string[]{"Ð", "&ETH;"}, 	// &#208; 	Eth (isländisch) 	
		new string[]{"Ñ", "&Ntilde;"}, 	// &#209; 	N mit Tilde 	
		new string[]{"Ô", "&Ocirc;"},	// &#212; 	O mit Circumflex 	
		new string[]{"Õ", "&Otilde;"}, 	// &#213; 	O mit Tilde 	
		new string[]{"×", "&times;"}, 	// &#215; 	Mal-Zeichen 	
		new string[]{"Ø", "&Oslash;"}, 	// &#216; 	O mit Schrägstrich 	
		new string[]{"Û", "&Ucirc;"}, 	// &#219; 	U mit Circumflex 	
		new string[]{"Ý", "&Yacute;"},	// &#221; 	Y mit Accent acute 	
		new string[]{"Þ", "&THORN;"}, 	// &#222; 	THORN (isländisch) 	
		new string[]{"â", "&acirc;"}, 	// &#226; 	a mit Circumflex 	
		new string[]{"ã", "&atilde;"}, 	// &#227; 	a mit Tilde 	
		new string[]{"å", "&aring;"}, 	// &#229; 	a mit Ring 	
		new string[]{"æ", "&aelig;"}, 	// &#230; 	a mit legiertem e 	
		new string[]{"ç", "&ccedil;"}, 	// &#231; 	c mit Häkchen 	
		new string[]{"ê", "&ecirc;"}, 	// &#234; 	e mit Circumflex 	
		new string[]{"ë", "&euml;"}, 	// &#235; 	e Umlaut 	
		new string[]{"î", "&icirc;"}, 	// &#238; 	i mit Circumflex 	
		new string[]{"ï", "&iuml;"}, 	// &#239; 	i Umlaut 	
		new string[]{"ð", "&eth;"}, 	// &#240; 	eth (isländisch) 	
		new string[]{"ñ", "&ntilde;"},	// &#241; 	n mit Tilde 	
		new string[]{"ô", "&ocirc;"}, 	// &#244; 	o mit Circumflex 	
		new string[]{"õ", "&otilde;"}, 	// &#245; 	o mit Tilde 	
		new string[]{"÷", "&divide;"}, 	// &#247; 	Divisions-Zeichen 	
		new string[]{"ø", "&oslash;"}, 	// &#248; 	o mit Schrägstrich 	
		new string[]{"û", "&ucirc;"}, 	// &#251; 	u mit Circumflex 	
		new string[]{"ý", "&yacute;"}, 	// &#253; 	y mit Accent acute 	
		new string[]{"þ", "&thorn;"}, 	// &#254; 	thorn (isländisch) 	
		new string[]{"ÿ", "&yuml;"} 	// &#255; 	y Umlaut
		*/
	};
}

