/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using MiBib;
using MiBibGtk;
using System;
using System.Collections;
using System.IO;
using System.Diagnostics;

class ProcessStart
{
	internal enum Actions { edit, enq, play }
	
	internal static void Execute(string path)
	{
		Actions action = Gui.gui.sc.Actions;
		Execute(action, path);
	}
	
	internal static void Execute(Actions action, string path)
	{
		//Console.WriteLine("path="+path);
		Ext.Typen typ = Ext.Path2Typ(path);
		//Console.WriteLine("typ="+typ);
		if (typ == Ext.Typen.audio) 
		{
			if (action != Actions.edit) Player.PlayFile(action != Actions.play, path);
			else SingEditWindow.Start(path);
			return;
		}
		else if (typ == Ext.Typen.playlist || typ == Ext.Typen.other)
		{
			ExecuteFile(path);
		}
		else if (Ext.ProgramIsDefinedInIni(typ))
		{
			string program = Ini.GetString("program_" + typ + "_" + action);
			Console.WriteLine("program=" + program);
			if (program == "fym")
			{
				if (typ == Ext.Typen.image) { Gui.gui.view.ShowImage(true, path); return; }
				
			}
			ExecuteFile(program, path);
		}
		else if (typ == Ext.Typen.executable || typ == Ext.Typen.info || typ == Ext.Typen.none || typ == Ext.Typen.unknown)
		{
			if (Directory.Exists(path))
			{
				//Console.WriteLine("action="+action);
				ExecuteFolder(action, path);
				return;
			}
			Output.Message(path + " is executable data or a link, it will not be opened for sake of security");
			return;
		}
		else 
		{
			Output.Message(path + " is unknown data, it will not be opened for sake of security\n\ninform your administrator if you want this file-type to be handled");
			return;
		}
		
		/*
		bool b = true;
		if (b == true) {} else
		 if (typ == Ext.Typen.image) 
		{
			if (action == Actions.edit) ExecuteFile(Ini.GetString("ImageProgram"), path);
			//else if (action == Actions.enq) ExecuteFile(path);
			else Gui.gui.view.ShowImage(true, path);
		}
		else if (typ == Ext.Typen.video) 
		{
			if (action == Actions.edit) ExecuteFile(Ini.GetString("VideoEditProgram"), path);
			else if (action == Actions.enq) ExecuteFile(Ini.GetString("VideoEnqProgram"), path);
			else ExecuteFile(Ini.GetString("VideoPlayProgram"), path);
		}
		else if (typ == Ext.Typen.browser) 
		{
			if (action == Actions.edit) ExecuteFile(Ini.GetString("BrowserEdit"), path);
			else if (action == Actions.enq) ExecuteFile(Ini.GetString("BrowserEnq"), path);
			else ExecuteFile(Ini.GetString("BrowserPlay"), path);
		}
		else if (typ == Ext.Typen.text) 
		{
			ExecuteFile(Ini.GetString("TextEditor"), path);
		}
		else if (   typ == Ext.Typen.other 
		         || typ == Ext.Typen.playlist
		        )
		{
			ExecuteFile(path);
		}
		else 
		{
			Output.Message(path + " is unknown data, it will not be opened for sake of security\n\ninform your administrator if you want this file-type to be handled");
			return;
		}
		*/
	}
	
	static internal void ExecuteFile(string path)
	{
		string program = "";
		if (SysInfo.Unix)
		{
			program = Ext.Path2Program(path);
			// if (program == "") Console.WriteLine("ProcessStart.ExecuteFile w/o program for " + path);
		}
		ExecuteFile(program, path);
	}
	
	static internal void ExecuteFile(string program, string path)
	{
		try
		{
			path = SysInfo.PathTreatment(path);
			path = PathTreatment(path);
			if (program == "") program = StartProcessCommand();
			if (program != "") Process.Start(program, path);
			else Process.Start(path);
		} 
		catch (Exception e)
		{
			//Message.Exception("program=" + program + "\npath=" + path, e);
			Gui.gui.Message("program=" + program + "\npath=" + path, e);
		}
	}
	
	internal static void ExecuteFolder(Actions action, string path)
	{
		// Console.WriteLine("ProcessStart.ExecuteFolder");
		if (action == Actions.edit) DirEditWindow.Start(path);
		else Gui.gui.view.UpdateFromDirectory(path);
	}
	
	static string StartProcessCommand()
	{
		string os = Ini.GetString("OS");
		if (os == "Linux")
		{
			string d = Ini.GetString("Desktop");
			if (d == "Gnome") return "gnome-open";
			else if (d == "KDE") return "kfmclient exec";
			else if (d == "FreeDesktop") return "xdg-open";
		}
		else if (os == "Windows") return ""; // "start";
		else if (os == "MacOS_X") return "open";
		return "";
	}
	
	static string PathTreatment(string path)
	{
		string sep = "\"";
		return sep + path + sep;
	}
}
