/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using MiBib;
using System;
using System.Collections;
using System.IO;

class RenameX
{
	bool files;
	bool folder;
	bool subfolder;
	internal string error = "";
	internal string log = SysInfo.PathTreatment(Var.strPathDat + "/temp.txt");
	string path;
	string replace;
	string with;
	
	internal RenameX(bool files, bool folder, bool subfolder,
	                 string path, string replace, string with)
    {
		this.files = files;
		this.folder = folder;
		this.subfolder = subfolder;
		this.path = path;
		this.replace = replace;
		this.with = with;
		LogInit();
		error += Folder(path);
	}
	
	string File(string path, string source, string dest)
	{
		LogAdd(source, dest);
		string error = Rename.Sing(path + "/" + source, path + "/" + dest);
		if (error != "") LogAddError(error);
		return error;
	}
	
	string Files(string path)
	{
		string error = "";
        ArrayList al = InOut.DirectoryFilesSorted(path);
		foreach (string str in al)
		{
			string old = Path.GetFileName(str);
			string neu = old.Replace(replace, with);
			if (old != neu) error += File(path, old, neu);
		}
        return error;
    }
	
	string Folder(string path)
	{
        string error = "";
        if (folder)
        {
			string neu = path.Replace(replace, with);
			if (path != neu)
			{
				LogAdd(path, neu);
				error += Rename.Folder(path, neu);
				if (error == "") path = neu;
				else LogAddError(error);
			}
        }
        if (files) error += Files(path);
        if (subfolder)
        {
        	ArrayList al = InOut.DirectoryFoldersSorted(false, path);
			foreach (string str in al)
			{
				error += Folder(str);
			}
        }
        return error;
	}
	
	void LogAdd(string source, string dest)
	{
		Log.Add(log, "");
		Log.Add(log, source);
		Log.Add(log, "->");
		Log.Add(log, dest);
	}
	
	void LogAddError(string error)
	{
		Log.Add(log, "ERROR - " + error);
	}
	
	void LogInit()
	{
		try
		{
			if (System.IO.File.Exists(log)) System.IO.File.Delete(log); 
		} catch (Exception e) { error += e.Message + "\n"; }
		Log.Add(log, "replace \"" + replace + "\" with \"" + with + "\"", true);
		Log.Add(log, "folder: " + path);
	}
}

