/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using MiBib;
using MiBibGtk;
using System;
using System.Collections;
using System.IO;

class DatabaseForm : Fenster
{
	internal static string title = "Database";
	
	internal static void Start()
	{
		Application.Init();
    	new DatabaseForm();
    	Application.Run();
	}
	
	ArrayList alFolder = new ArrayList();
	CheckButton chbAll = new CheckButton("all");
	string file = SysInfo.IniFile(SysInfo.DirFilePart);
	VBox cnt = new VBox();
	
	DatabaseForm() : base(title, Var.icon)
	{
		Init();
		Load();
		this.ShowAll();
	}
	
	void Add_Clicked(object obj, EventArgs args)
	{
		string str = Dialogs.GetFolder("add folder", this, false);
		if (str != "") AddFolder(str);
	}
	
	void All_Toggled(object o, EventArgs args)
	{
		foreach (CheckButton chb in alFolder) chb.Active = chbAll.Active;
	}
	
	void AddFolder(string dir)
	{
		if (dir == "") return;
		bool active = true;
		if (dir.Substring(0, 1) == "#")
		{
			active = false;
			dir = dir.Substring(1, dir.Length - 1);
			dir = dir.Trim();
		}
		CheckButton chb = new CheckButton(dir);
		chb.Active = active;
		cnt.Add(chb);
		alFolder.Add(chb);
		chb.Show();
	}
	
	void Create_Clicked(object obj, EventArgs args)
	{
		Update(true);
	}
	
	void Edit_Clicked(object obj, EventArgs args)
	{
		ProcessStart.ExecuteFile(file);
	}
	
	void Init()
	{
		Button button;
		this.Add(cnt);
		
		HBox bx = new HBox();
		cnt.Add(bx);
		
		button = new Button("Add folder");
		button.Clicked += new EventHandler(Add_Clicked);
		bx.Add(button);
		
		button = new Button("Edit list");
		button.Clicked += new EventHandler(Edit_Clicked);
		bx.Add(button);
		
		button = new Button("Load list");
		button.Clicked += new EventHandler(Load_Clicked);
		bx.Add(button);
		
		button = new Button("Save list");
		button.Clicked += new EventHandler(Save_Clicked);
		bx.Add(button);
		
		button = new Button("Create database");
		button.Clicked += new EventHandler(Create_Clicked);
		bx.Add(button);
		
		button = new Button("Update database");
		button.Clicked += new EventHandler(Update_Clicked);
		bx.Add(button);
		
		chbAll.Toggled += new EventHandler(All_Toggled);
		cnt.Add(chbAll);
		
	}
	
   	void Load_Clicked(object obj, EventArgs args)
	{
   		for (int i = alFolder.Count - 1; i >= 0; i--)
   		{
   			CheckButton chb = (CheckButton)alFolder[i];
   			cnt.Remove(chb);
   			alFolder.Remove(chb);
   			chb.Dispose();
   		}
   		Load();
	}
   	
    void Load()
    {
    	ArrayList al = InOut.File2ArrayList(file, false);
    	foreach (string str in al)
    	{
    		AddFolder(str);
    	}
    	chbAll.Active = true;
    }
    
	void Save_Clicked(object obj, EventArgs args)
	{
		try { File.Delete(file); }
		catch (Exception e) 
		{
			Message(MessageType.Error, e.Message);
			return;
		}
		foreach (CheckButton chb in alFolder)
		{
			string dir = "";
			if (!chb.Active) dir += "# ";
			dir += chb.Label;
			Log.Add(file, dir, false);
		}
	}
   	
   	void Update(bool create)
   	{
   		string error = "";
   		string message = "please comfirm\n\n";
   		if (create) message += "- DROP DATABASE\n\n";
   		
   		ArrayList al = new ArrayList();
   		foreach (CheckButton chb in alFolder)
		{
   			if (chb.Active) 
   			{
   				al.Add(chb.Label);
   				message += "- update " + chb.Label + "\n";
   				if (!Directory.Exists(chb.Label)) error += "directory does not exist: " + chb.Label + "\n";
   			}
		}
   		if (error != "")
   		{
   			Message(MessageType.Error, error);
   			return;
   		}
   		if (!DialogForm.YesNo(this, "confirm", message)) return;
   		if (create) 
   		{
   			Database.Drop(false);
   			Database.Create();
   		}
   		error = Database.UpdateFromArrayList(al, false, create);
   		if (error != "")
   		{
   			if (DialogForm.YesNo(this, "Show log?", "errors occured, show log?")) ProcessStart.Execute(Mvar.logError);
   		}
   		else Message("done");
   	}
   	
   	void Update_Clicked(object obj, EventArgs args)
	{
		Update(false);
	}
   	
   	
}
