/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using MiBib;
using MiBibGtk;
using System;
using System.Collections;

class DirEditWindow : Fenster
{
	internal static void Start(string path)
	{
		Application.Init();
		new DirEditWindow(path);
		Application.Run();
	}
	
	DirEditWindow(string path) : base(path, Var.icon)
	{
		lastPath = path;
		Init();
		Update();
	}
	
	AttachOptions ao = AttachOptions.Shrink;
	Box bx = new VBox();
	Entry folder = new Entry();
	Entry main = new Entry();
	Entry name = new Entry();
	Entry path = new Entry();
	Entry rnd = new Entry();
	string lastPath;
	Table table = new Table(6, 2, false);
	UInt32 y = 0;
	
	void Init()
	{
		this.Move(Ini.GetInt("StartPositionLeft"), Ini.GetInt("StartPositionTop"));
		this.SetDefaultSize(900, 600);
		//this.SetPosition(WindowPosition.Center);
		
		this.Add(bx);
		
		TableInit();
		
		// ButtonBox
		Button btn;
		ButtonBox btnbx = new HButtonBox();
		
		btnbx.BorderWidth = Var.space;
		btnbx.Layout = ButtonBoxStyle.Spread;
		btnbx.Spacing = (int)Var.space;
		bx.Add(btnbx);
		
		btn = Buttons.LevelUp();
		btn.Clicked += new EventHandler(LevelUp_Clicked);
		btnbx.Add(btn);
		
		btn = new Button("_move");
		btn.Clicked += new EventHandler(Move_Clicked);
		btnbx.Add(btn);
		
		btn = new Button("_rename");
		btn.Clicked += new EventHandler(Rename_Clicked);
		btnbx.Add(btn);
		
		btn = new Button("_rename and exit");
		btn.Clicked += new EventHandler(RenameAndExit_Clicked);
		btnbx.Add(btn);
		
		this.ShowAll();
		
	}
	
	void LevelUp_Clicked(object o, EventArgs ea)
	{
		DirEditWindow.Start(System.IO.Path.GetDirectoryName(lastPath));
	}
	
	void Move_Clicked(object o, EventArgs ea)
	{
		string dest = System.IO.Path.GetDirectoryName(lastPath) + "/" + folder.Text;
		if (lastPath != dest) Rename_Clicked(null, null);
		string newFolder = Dialogs.GetFolder("move to", this, false);
		if (newFolder == "") return;
		dest = newFolder + "/" + folder.Text;
		string error = RenameFolder(lastPath, dest);
		if (error != "") return;
		new MySql3(Mvar.db, Mvar.pw, Mvar.server, Mvar.user,
		           "UPDATE album SET dir_id=" + Dir.Path2Id(dest)
		                    + " WHERE path=\"" + dest + "\"");
		
	}
	
	void Rename_Clicked(object o, EventArgs ea)
	{
		string dest = System.IO.Path.GetDirectoryName(lastPath) + "/" + folder.Text;
		RenameFolder(lastPath, dest);
	}
	
	void RenameAndExit_Clicked(object o, EventArgs args)
	{
		Rename_Clicked(o, args);
		This_Delete(null, null);
	}
	
	string RenameFolder(string source, string dest)
	{
		string error = Rename.Folder(source, dest);
		if (error != "") Message(MessageType.Error, error);
		else 
		{
			lastPath = dest;
			Update();
		}
		return error;
	}
	
	void TableAttach(string text, ref Entry entry, bool editable)
	{
		UInt32 x = 0;
		Label label = new Label(text);
		//label.Justify = Justification.Left;
		table.Attach(label, x, x+1, y, y+1, ao, ao, 0, 0);
		x++;
		entry.IsEditable = editable;
		table.Attach(entry, x, x+1, y, y+1);
		y++;
	}
	
	void TableInit()
	{
		table.BorderWidth = Var.space;
		table.ColumnSpacing = table.RowSpacing = Var.space;
		bx.Add(table);
		
		TableAttach(di.rnd[1], ref rnd, false);
		TableAttach("folder", ref folder, true);
		TableAttach("name", ref name, false);
		TableAttach("path", ref path, false);
		TableAttach("main", ref main, false);
	}
	
	void Update()
	{
		folder.Text = System.IO.Path.GetFileName(lastPath);
		path.Text = lastPath;
		
		string str = Peculiar.Substitute(lastPath);
		rnd.Text = Rnd.Check(ref str).ToString();
		name.Text = str;
		
		Album album = new Album(lastPath);
		main.Text = MySql3.Id2Text(Mvar.db, Mvar.pw, Mvar.server, Mvar.user,
		                          "dir", "name", album.dir_id);
	}
	
}
