/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gdk;
using Gtk;
using MiBib;
using MiBibGtk;
using System;
using System.Collections;

class Gui : Fenster
{
	// rows*rows -> number of results to be shown
	internal static uint rows = (uint)Ini.GetInt("StartColsRows"); //standardRowsAndCols;
	
	// refers to the limit of the above value (position in the array SearchControl.limits)
	internal static int standardLastLimitAlbumCover = 1; 
	
	internal static Gui gui;
	
	internal static void Rect(out int left, out int top, out int width, out int height)
	{
		gui.GetPosition(out left, out top);
		gui.GetSize(out width, out height);
	}
	
	internal static int FrameWidth()
	{
		// int left;
		// int top;
		// gui.GetPosition(out left, out top);
		// Rectangle rect = gui.view.Allocation;
		// int i = rect.Left - left;
		// Console.WriteLine("Gui.FrameWidth=" + i);
		// return i;
		return GuiVar.approxBorderWindow;
	}
	
	internal static void Start(bool StartWithRandomCovers)
	{
		Application.Init();
		gui = new Gui();
		string error = MySqlMV.ConnectionCheck();
		if (error != "")
		{
			Console.WriteLine(error);
			DatabaseForm.Start();
		}
		
		if (StartWithRandomCovers)
		{
			Rnd rnd = new Rnd(true, (int)rows * (int)rows);
			ArrayList al = rnd.alPath;
			rows = NumberControl.Results2NumberRows(al.Count);
			//if (StartWithRandomCovers) gui.Update(rows, al, "");
			gui.Update(rows, al, "");
		}
		
		for (int i = 0; i < SearchControl.limits.Length; i++)
		{
			if (rows * rows == SearchControl.limits[i]) standardLastLimitAlbumCover = i;
		}
		
		gui.ShowAll();
		if (!Ini.GetBool("StartWithKeyboard")) gui.OnMenuKeyboard(null, null);
		Application.Run();
	}
	
	VBox controls = new VBox();
	internal Entry entry;
	internal FolderImages fi = new FolderImages();
	bool fullscreen;
	internal MenuBar mb = new MenuBar();
	uint padding = 1;
    internal PlayerControl pc = new PlayerControl();
	internal SearchControl sc = new SearchControl();
	internal View view = new View();
	
	//string saveOnExit = "fymdat/z_wp_main.ini";
	
	internal Gui() : base(Var.programNameBoth, Var.icon)
	{
		Init();
		string error = "";
		if (Ini.GetBool("SaveOnExit")) error = AppearanceFromFile(Var.strPathDat + "z_wp_main.ini");
		if (!Ini.GetBool("SaveOnExit") || error != "") 
		{
			this.SetDefaultSize(Ini.GetInt("DefaultWidth"), Ini.GetInt("DefaultHeight"));
			if (Ini.GetBool("StartMaximized")) this.Maximize();
			if (Ini.GetBool("StartWithFullscreen")) this.Fullscreen();
			if (Ini.GetBool("WindowPositionCenter")) this.SetPosition(WindowPosition.Center);
			else this.Move(Ini.GetInt("StartPositionLeft"), Ini.GetInt("StartPositionTop"));
		}
		
		this.Focus = sc.ntrSearch;
		//this.Icon = new Resource().Get("next.png");
		//this.OnResize += new EventHandler(this_Resize); todo: sonst werden die FolderImages nicht ordentlich neu gezeichnet
	}
	
	internal void HistoryBack()
	{
		HistoryItem hi = History.Backwards();
		if (hi == null) return;
		view.Update(hi);
	}
	
    internal void HistoryForward()
	{
		HistoryItem hi = History.Forwards();
		if (hi == null) return;
		view.Update(hi);
	}
	
    void Go_Clicked(object o, EventArgs args)
    {
    	ProcessStart.Execute(entry.Text);
    }
    
	void Init()
	{
		VBox all = new VBox();
		this.Add(all);
		
		HBox menu = new HBox();
		all.PackStart(menu, false, false, 0);
		
		InitMenuBar();
		menu.PackStart(mb, false, false, padding);
		
		HBox address = new HBox();
		menu.Add(address);//PackStart(address, false, false, 0);
    	entry = new Entry();
		address.PackStart(entry, true, true, 0);
		Button button = new Button(di.go[1]);
		button.Clicked += new EventHandler(Go_Clicked);
		address.PackStart(button, false, false, 0);
		
		VBox gw = new VBox(false, 0);
		all.Add(gw);
		
		HPaned main = new HPaned();
		
		//HBox main = new HBox();
		gw.Add(main);
		
		//main.PackStart(view, true, true, padding);
		main.Pack1(view, true, false);
		
		//main.PackEnd(controls, false, false, padding);
		main.Pack2(controls, false, false);
		
		
		
		controls.PackStart(sc, false, false, padding);
		
		HBox lower = new HBox();
		controls.PackStart(lower, true, true, padding);
		
    	lower.PackStart(fi, true, true, 0);
    	
    	lower.PackStart(pc, false, false, padding);
    	
    	// SystemTrayStatusIcon_Init();
    	
    	
	}
	
	void InitMenuBar()
	{
		
		AccelGroup agrp = new AccelGroup();
		AddAccelGroup(agrp);
		
		Menu menu;
		MenuItem mi;
		
		menu = new Menu();
		mi = new MenuItem("_View");
		mi.Submenu = menu;
		mb.Append(mi);
		
		// Stock.LeaveFullscreen
		mi = new ImageMenuItem(Stock.Fullscreen, agrp);
		mi.AddAccelerator("activate", agrp, new AccelKey(Gdk.Key.F11, Gdk.ModifierType.None, AccelFlags.Visible));
		mi.Activated += new EventHandler(OnMenuFullscreen); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		mi = new MenuItem("Keyboard");
		mi.Activated += new EventHandler(OnMenuKeyboard); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		menu = new Menu();
		mi = new MenuItem("_Settings");
		mi.Submenu = menu;
		mb.Append(mi);
		
		mi = new MenuItem(DatabaseForm.title);
		mi.Activated += new EventHandler(OnMenuDatabase); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		mi = new MenuItem("_Ini Edit");
		mi.Activated += new EventHandler(OnMenuIniEdit); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		mi = new MenuItem(ListsForm.title);
		mi.Activated += new EventHandler(OnMenuLists); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		mi = new MenuItem(ReportsForm.title);
		mi.Activated += new EventHandler(OnMenuReports); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		menu = new Menu();
		mi = new MenuItem("_Player");
		mi.Submenu = menu;
		mb.Append(mi);
		
		mi = new ImageMenuItem(Stock.Home, agrp);
		mi.AddAccelerator("activate", agrp, new AccelKey(Gdk.Key.Home, Gdk.ModifierType.Mod1Mask, AccelFlags.Visible));
		mi.Activated += new EventHandler(OnMenuHome); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		mi = new ImageMenuItem(di.play[3], agrp);
		//mi.AddAccelerator("activate", agrp, new AccelKey(Gdk.Key.Pause, Gdk.ModifierType.None, AccelFlags.Visible));
		mi.Activated += new EventHandler(OnMenuMediaPlay); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		mi = new ImageMenuItem(di.playpause[3], agrp);
		mi.AddAccelerator("activate", agrp, new AccelKey(Gdk.Key.Pause, Gdk.ModifierType.None, AccelFlags.Visible));
		mi.Activated += new EventHandler(OnMenuMediaPause); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		menu = new Menu();
		mi = new MenuItem("_?");
		mi.Submenu = menu;
		mb.Append(mi);
		
		mi = new ImageMenuItem(Stock.Info, agrp);
		// mi.AddAccelerator("activate", agrp, new AccelKey(Gdk.Key.Home, Gdk.ModifierType.Mod1Mask, AccelFlags.Visible));
		mi.Activated += new EventHandler(OnMenuInfo); // todo 04.07.2008 sharpdevelop
		menu.Append(mi);
		
		
		
		
		
		
		/*
		ToggleActionEntry it = new ToggleActionEntry("OnFullscreen", Stock.Fullscreen, // null,
                    "_Fullscreen", "F11",
                    "Toggle Fullscreen Mode", null, false);
                    
        agrp.Add(it);
		*/
	}
	
    internal void ShowAlbumImages(string path)
	{
		fi.Update(path);
	}
	
	/*
	// SystemTray
	StatusIcon systemTrayStatusIcon; 
	Menu systemTrayStatusIconMenu;
	void SystemTrayStatusIcon_Activate(object o, EventArgs args)
	{
		Console.WriteLine("systemTrayStatusIcon.Activate -> left-click");
	}
	void SystemTrayStatusIcon_Init()
	{
		systemTrayStatusIcon = StatusIcon.NewFromStock(Stock.Info);
		systemTrayStatusIcon.Activate += new EventHandler(SystemTrayStatusIcon_Activate); // left-click
		systemTrayStatusIcon.PopupMenu += new PopupMenuHandler(SystemTrayStatusIcon_PopupMenu); // right-click

		systemTrayStatusIconMenu = new Menu();
		ImageMenuItem mi = new ImageMenuItem("Quit");
		mi.Activated += new EventHandler(SystemTrayStatusIconMenu_Activated);
		mi.Image = new Gtk.Image(Stock.Quit, IconSize.Menu);
		systemTrayStatusIconMenu.Add(mi);
		systemTrayStatusIconMenu.ShowAll();
    }
    void SystemTrayStatusIcon_PopupMenu(object o, PopupMenuArgs args)
	{
		systemTrayStatusIconMenu.Popup(null, null, SystemTrayStatusIcon_PositionMenu, 3, Gtk.Global.CurrentEventTime);
	}
	void SystemTrayStatusIcon_PositionMenu(Menu menu, out int x, out int y, out bool push_in) // wrapper for incompatible PositionMenu in StatusIcon
	{
		StatusIcon.PositionMenu(menu, out x, out y, out push_in, systemTrayStatusIcon.Handle);
	}
	void SystemTrayStatusIconMenu_Activated(object o, EventArgs args)
	{
		Application.Quit();
	}
	*/
	
	internal void Update(uint rows, ArrayList al, string fullPath)
    {
    	HistoryItem hi = new HistoryItem(Gui.gui.sc.album.Active, sc.cover.Active, 
    	                                 rows, al, fullPath);
		History.Insert(hi);
		view.Update(hi);
    }
    
    void OnMenuDatabase(object o, EventArgs args) { DatabaseForm.Start(); }
	void OnMenuFullscreen(object o, EventArgs args)
	{
		fullscreen = !fullscreen;
		if (fullscreen) Fullscreen(); else Unfullscreen();
	}
	void OnMenuHome(object o, EventArgs args) { pc.Home(); }
	void OnMenuInfo(object o, EventArgs args) { InfoWindow.Start(); }
	void OnMenuIniEdit(object o, EventArgs args)
	{
		string file = SysInfo.IniFile(SysInfo.IniFilePart);
		EditForm.Start(file);
		string error = Ini.Init(file);
		if (error != "") Console.WriteLine(error);
	}
	void OnMenuKeyboard(object o, EventArgs args) { sc.KeyboardToggle(); }
	void OnMenuLists(object o, EventArgs args) { ListsForm.Start(); }
	void OnMenuMediaPlay(object o, EventArgs args) { Input.Exec(di.play[0]); }
	void OnMenuMediaPause(object o, EventArgs args) { Input.Exec(di.playpause[0]); }
	void OnMenuReports(object o, EventArgs args) { ReportsForm.Start(); }
	
	
}
