/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gdk;
using Gtk;
using MiBib;
using System;

class Img
{
	internal static int big = 735;
	internal static int button = 24;
	internal static int medium = 650;
	internal static int mini = 50;
	internal static int small = 161;
	internal static int thumb = 120;
	internal static int xmax = 1000;
	internal static int ymax = 735;
	// internal static Pixbuf error = Resource.Pxbf("cat.jpg");
	// internal static Pixbuf noCover = Resource.Pxbf("cat.jpg");
	internal static string folder = Ini.GetString("CoverName"); // "folder.jpg";
	
	internal static string Cover(string path)
	{
		return path + "/" + folder;
	}
	
	internal static Pixbuf FitIn(bool cover, string path, int xmax, int ymax)
	{
		return FitIn(cover ? Cover(path) : path, xmax, ymax);
	}
	
	internal static Pixbuf FitIn(Pixbuf p, int xmax, int ymax)
	{
		int x = xmax;
		int y = Width2Height(p.Width, p.Height, xmax);
		if (y > ymax)
		{
			y = ymax;
			x = Height2Width(p.Width, p.Height, ymax);
		}
		return p.ScaleSimple(x, y, InterpType.Nearest);
	}
	
	internal static Pixbuf FitIn(string file, int xmax, int ymax)
	{
		Pixbuf p;
		try { p = new Pixbuf(file); } catch { return null; }
		return FitIn(p, xmax, ymax);
	}
	
	internal static Pixbuf Original(string path, bool cover, bool substitute)
	{
		Pixbuf p;
		if (cover) path = Cover(path);
		try { p = new Pixbuf(path); } 
		catch { p = null; } // substitute ? noCover : null; }
		return p;
	}
	/*
	internal static Pixbuf OriginalCover(bool substitute, string dir)
	{
		return Original(substitute, Cover(dir));
	}
	*/
	static Pixbuf Resize(string file, int newWidth, InterpType it)
	{
		// Pixbuf p = Original(true, full);
		Pixbuf p = Original(file, false, true);
		return p.ScaleSimple(newWidth, Width2Height(p.Width, p.Height, newWidth), InterpType.Nearest);
	}
	static Pixbuf Resize(int newWidth, InterpType it, string resource)
	{
		Pixbuf p = Resource.GetPixbuf(resource);
		return p.ScaleSimple(newWidth, Width2Height(p.Width, p.Height, newWidth), InterpType.Nearest);
	}
	static int Width2Height(int cx, int cy, int newWidth)
	{
		return cx * cy == 0 ? 0 : (int)Math.Floor(newWidth / ((double)cx/(double)cy));
	}
	
	static int Height2Width(int cx, int cy, int newHeight)
	{
		return cx * cy == 0 ? 0 : (int)Math.Floor(newHeight / ((double)cy/(double)cx));
	}
	
	// ##############
	// ### widths ###
	// ##############
	
	internal static Pixbuf Max(bool cover, string file)
	{
		return FitIn(cover, file, xmax, ymax);
	}
	
	internal static Pixbuf Big(bool cover, string file)
	{
		return Resize(cover ? Cover(file) : file, big, InterpType.Nearest);
	}
	internal static Pixbuf Button(string resource)
	{
		return Resize(button, InterpType.Hyper, resource);
	}
	internal static Pixbuf Medium(bool cover, string file)
	{
		return Resize(cover ? Cover(file) : file, medium, InterpType.Nearest);
	}
	internal static Pixbuf Mini(bool cover, string file)
	{
		return Resize(cover ? Cover(file) : file, mini, InterpType.Nearest);
	}
	internal static Pixbuf Small(bool cover, string file)
	{
		return Resize(cover ? Cover(file) : file, small, InterpType.Nearest);
	}
	internal static Pixbuf Thumb(bool cover, string file)
	{
		return Resize(cover ? Cover(file) : file, thumb, InterpType.Nearest);
	}
	internal static Pixbuf User(bool cover, string file, int width)
	{
		return Resize(cover ? Cover(file) : file, width, InterpType.Nearest);
	}
	
	
}

/* Gdk.InterpType Enumeration

Member Name 	Description
Nearest			Nearest neighbor sampling; this is the fastest and lowest quality mode. Quality is normally unacceptable when scaling down, but may be OK when scaling up. [Edit] 
Tiles 			This is an accurate simulation of the PostScript image operator without any interpolation enabled. Each pixel is rendered as a tiny parallelogram of solid color, the edges of which are implemented with antialiasing. It resembles nearest neighbor for enlargement, and bilinear for reduction. [Edit] 
Bilinear 		Best quality/speed balance; use this mode by default. Bilinear interpolation. For enlargement, it is equivalent to point-sampling the ideal bilinear-interpolated image. For reduction, it is equivalent to laying down small tiles and integrating over the coverage area. [Edit] 
Hyper 			This is the slowest and highest quality reconstruction function. It is derived from the hyperbolic filters in Wolberg's "Digital Image Warping", and is formally defined as the hyperbolic-filter sampling the ideal hyperbolic-filter interpolated image (the filter is designed to be idempotent for 1:1 pixel mapping). [Edit] 

*/
