/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gdk;
using Gtk;
using System;
using System.Collections;

internal class List : ScrolledWindow
{
	internal enum Type { album, artist, cover, details, none, sing, title, various }
	
	internal ArrayList artists = new ArrayList();
	
	int col;
	const int colStandard = 3;
	internal ListStore store;
	internal TreeView treeView;
	TreeViewColumn[] column = new TreeViewColumn[colStandard + 3];
	string sequence = "";
	Type type = Type.sing;
	
	internal List() : base()
	{
		this.ShadowType = ShadowType.None;//.EtchedIn;
		this.SetPolicy(PolicyType.Automatic, PolicyType.Automatic);
		
		store = 
			new ListStore(
			typeof(bool),
			typeof(int),
			typeof(Pixbuf),
			typeof(string),
			typeof(string),
			typeof(string),
			typeof(string)
		);
		
		treeView = new TreeView(store);
		treeView.RulesHint = true;
		//treeView.SearchColumn =(int)ColumnNumber.Description;
		
		col = 0;
		AddStandardColumns();
		
		this.Add(treeView);
	}
	
	void AddColumn(string title)
	{
		column[col] = new TreeViewColumn(title, new CellRendererText(), "text", col);
		column[col].Expand = false;
		//column[col].IsFloating = true;
		//column[col].MaxWidth = 200;
		//column[col].MinWidth = 100;
		column[col].Reorderable = true;
		column[col].Resizable = true;
		column[col].Sizing = TreeViewColumnSizing.Autosize;
		column[col].SortColumnId = col;
		column[col].Spacing = 50;
		//column[col].Width = 100;
		treeView.AppendColumn(column[col]);
		col++;
	}
	/*
	// raus wg. selection
	void AddId(int id)
	{
		if (type == Type.album) Selection.albums.Add(id);
		else if (type == Type.artist) artists.Add(id);
		else Selection.sings.Add(id);
	}
	*/
	/*
	void AddOtherColumns()
	{
		for (int i = col; i < column.Length; i++) AddColumn("column" + i);
	}
	*/
	
	void AddStandardColumns()
	{
		CellRendererText rendererText;
		
		// checkbox
		CellRendererToggle rendererToggle = new CellRendererToggle();
		rendererToggle.Toggled += new ToggledHandler(ItemToggled);
		column[col] = new TreeViewColumn("", rendererToggle, "active", col);
		rendererToggle.Active = true;
		rendererToggle.Activatable = true;
		rendererToggle.Visible = true;
		column[col].Sizing = TreeViewColumnSizing.Fixed;
		column[col].FixedWidth = 20;
		column[col].Reorderable = true;
		column[col].SortColumnId = col;
		treeView.AppendColumn(column[col]);			
		col++;
		
		// id
		rendererText = new CellRendererText();
		column[col] = new TreeViewColumn("id", rendererText, "text", col);
		//column[col].MaxWidth = 0;
		column[col].SortColumnId = col;
		column[col].Visible = false;
		treeView.AppendColumn(column[col]);
		col++;
		
		// pixbuf
		CellRendererPixbuf renderer = new CellRendererPixbuf();
		//rendererToggle.Toggled += new ToggledHandler(ItemToggled);
		column[col] = new TreeViewColumn("cover", renderer, "pixbuf", col);
		//rendererToggle.Active = true;
		//rendererToggle.Activatable = true;
		rendererToggle.Visible = true;
		//column[col].Sizing = TreeViewColumnSizing.Fixed;
		//column[col].FixedWidth = 20;
		//column[col].Reorderable = true;
		column[col].SortColumnId = col;
		column[col].Visible = false;
		treeView.AppendColumn(column[col]);
		col++;
	}
	
	internal void ClearSelection()
	{
		ToggleAll(false);
	}
	
	void Fill(ArrayList al, bool cover)
	{
		if (type == Type.sing) FillSing(al, cover);
		else if (type == Type.album) FillAlbum(al, cover);
		else if (type == Type.title) FillTitle(al, cover);
		else if (type == Type.various) FillVarious(al, cover);
	}
	
	void FillAlbum(ArrayList al, bool cover)
	{
		foreach (int id in al)
		{
			Album o = new Album(id);
			store.AppendValues(Selection.Contains(List.Type.album, id),//s.Contains(id),
			    id,
			    cover ? Img.Thumb(true, o.path) : null,
			    "artist", "title", "year"
			);
		}
	}
	
	void FillSing(ArrayList al, bool cover)
	{
		foreach (int id in al)
		{
			Sing o = new Sing(id);
			store.AppendValues(Selection.Contains(Type.sing, id),
			    id,
			    cover ? Img.Thumb(true, o.path) : null,
			    "artist", "title", "albumYear"
			);
		}
	}
	
	void FillTitle(ArrayList al, bool cover)
	{
		foreach (int id in al)
		{
			Sing o = new Sing(id);
			store.AppendValues(Selection.Contains(Type.sing, id),
			    id,
			    cover ? Img.Thumb(true, o.path) : null,
			    "title"
			);
		}
	}
	
	void FillVarious(ArrayList al, bool cover)
	{
		foreach (int id in al)
		{
			Sing o = new Sing(id);
			store.AppendValues(Selection.Contains(Type.sing, id),
			    id,
			    cover ? Img.Thumb(true, o.path) : null,
			    "artist", "title"
			);
		}
	}
	
	void ItemToggled(object o, ToggledArgs args)
	{Console.WriteLine("toggled: ");
		Gtk.TreeIter iter;
		if (store.GetIterFromString(out iter, args.Path))
		{
			bool b = (bool)store.GetValue(iter, 0);
			int id = (int)store.GetValue(iter, 1);
			Console.WriteLine("" + b + " " + id);
			Selection.Toggle(type, !b, id);
			store.SetValue(iter, 0, !b);
		}
	}
	
	internal void PlaySelection(Type type, bool enq)
    {
		Selection.PlaySelection(type, enq);
		ClearSelection();
    }
    
    void RemoveColumns()
	{
		col = colStandard + sequence.Length;
		while (col < column.Length) try { treeView.RemoveColumn(column[col++]); } catch {}
	}
	/*
    // raus wg. selection
	void RemoveId(int id)
	{
		if (type == Type.album) 
			Selection.Toggle(type, false, id);
		else if (type == Type.artist) artists.Remove(id);
		else Selection.sings.Remove(id);
	}
	*/
	void RenameColumns()
	{
		col = colStandard;
		foreach (char ch in sequence)
		{
			string str = ch.ToString();
			string title = "";
			if (str == di.artist[0]) title = di.artist[1];
			else if (str == di.folder[0]) title = di.folder[1];
			else if (str == di.name[0]) title = di.name[1];
			else if (str == di.title[0]) title = di.title[1];
			else if (str == di.year[0]) title = di.year[1];
			else title = "error";
			
			if (treeView.Columns.Length <= col) AddColumn(title);
			else column[col++].Title = title;
		}
	}
	
	internal int ShowSelection(Type type, string sequence, bool showCover)
    {
		ArrayList al = Selection.GetArrayList(type);
		//if (type == Type.album) al = Selection.albums;
		//else if (type == Type.artist) al = artists;
		//else 
		//{
		//	al = Selection.sings;
			//sequence = Sings.sequence
			//type = Type.sing;
		//}
		//else return 0;Error.Message("List.ShowSelection type '" + type + "' unknown");
		Update(type, sequence, al, showCover);
		return al.Count;
    }
    
	internal void Sort()
	{
		treeView.Columns[0].SortOrder = SortType.Ascending;
		//treeView.Columns[1].Click();
		//foreach (TreeViewColumn c in column)
		//{
			//c.SortOrder = SortType.Ascending;
			
		//}
	}
	
    internal void ToggleAll(bool on)
	{
		Gtk.TreeIter iter;
		int row = 0;
		while (store.GetIterFromString(out iter, row.ToString()))
		{
			int id = (int)store.GetValue(iter, 1);
			//Console.Write("ids: ");
			//Console.WriteLine("toggled {0} with value {1}", args.Path, b);
			//Console.WriteLine("id: " + id);
			store.SetValue(iter, 0, on);
			Selection.Toggle(type, on, id);
			//RemoveId(id);//ids.Remove(id);
			//if (on) Selection.Toggle(type, true, id);//AddId(id);//ids.Add(id);
			row++;
		}
		//IdCheck();
	}
	
	internal void Update(Type type, string sequence, ArrayList al, bool cover)
	{
		Console.WriteLine("type: " + type);
		
		if (type == Type.details)
		{
			//Output.Message("details");
		}
		else UpdateTreeView(type, sequence, al, cover);
	}
	
	internal void UpdateTreeView(Type type, string sequence, ArrayList al, bool cover)
	{
		store.Clear();
		if (this.type != type || this.sequence != sequence)
		{
			this.sequence = sequence;
			this.type = type;
			RemoveColumns();
			RenameColumns();
		}
		column[2].Visible = cover;
		Fill(al, cover);
	}
	
}
