/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gdk;
using Gtk;
using MiBib;
using System;
using System.Collections;

class Menus
{
	static char sep = '"'; // todo: might appear in a Linux filename
	
	static void MenuItem_Activated(object o, EventArgs args)
	{
		MenuItem mi = (MenuItem)o;
		string[] astr = mi.Name.Split(sep);
		if (astr[1] == di.enq[0]) Player.PlayFile(true, astr[0]);
		else if (astr[1] == di.enq_folder[0]) Player.PlayFolder(true, astr[0]);
		else if (astr[1] == di.play[0]) Player.PlayFile(false, astr[0]);
		else if (astr[1] == di.play_folder[0]) Player.PlayFolder(false, astr[0]);
		else if (astr[1] == di.openExtDir[0]) ProcessStart.ExecuteFile(astr[0]);
		else if (astr[1] == di.openExtFile[0]) ProcessStart.Execute(astr[0]);
		else if (astr[1] == di.openExtImg[0]) ProcessStart.ExecuteFile(astr[0]);
		else if (astr[1] == di.openDefApp[0]) ProcessStart.ExecuteFile(astr[5], astr[0]);
		else if (astr[1] == di.openStandApp[0]) ProcessStart.ExecuteFile("", astr[0]);
		else if (astr[1] == di.rename[0]) SingEditWindow.Start(astr[0]);
		else if (astr[1] == di.rename_folder[0]) DirEditWindow.Start(astr[0]);
		else if (astr[1] == di.showImage[0]) ProcessStart.Execute(astr[0]);
		else if (astr[1] == di.showTracks[0]) ProcessStart.ExecuteFolder(ProcessStart.Actions.play, astr[0]);//Execute(astr[0]);
		else if (astr[1] == di.xrename_folder[0]) XrenameWindow.Start(astr[0]);
		else Message.Show("no action supported in MenuItem_Activated for:\n\n" + mi.Name, "What to do with?");
		//else ProcessStart.Execute(astr[0]);
	}
	
	internal static ImageMenuItem Item(string[] di, string path)
	{
		ImageMenuItem mi = new ImageMenuItem(di[1]);
		mi.Activated += new EventHandler(MenuItem_Activated);
		if (di[3] != "") try { mi.Image = new Gtk.Image(di[3], IconSize.Menu); } catch(Exception) { }
		mi.Name = path + sep + String.Join(sep.ToString(), di);
		return mi;
	}
		
	static internal Menu File(Ext.Typen typ, string path)
	{
		string folder = System.IO.Path.GetDirectoryName(path);
		Menu menu = new Menu();
		
		if (Ext.ProgramIsDefinedInIni(typ))
		{
			ArrayList programs = new ArrayList();
			//foreach (string str in Enum.GetNames(typeof(Ext.Typen)))
			foreach (string action in Enum.GetNames(typeof(ProcessStart.Actions)))
			{
				string program = Ini.GetString("program_" + typ + "_" + action);
				if (program != "" && !programs.Contains(program)) programs.Add(program);
			}
			foreach (string program in programs)
			{
				di.openDefApp[1] = "open with " + program;
				di.openDefApp[4] = program;
				//menu.Add(new MenuItem("open with " + program));
				menu.Add(Item(di.openDefApp, path));
			}
		}
		
		if (typ == Ext.Typen.audio)
		{
			menu.Add(Item(di.play, path));
			menu.Add(Item(di.enq, path));
		}
		else if (typ == Ext.Typen.image)
		{
			menu.Add(Item(di.showImage, path));
			menu.Add(Item(di.openExtImg, path));
		}
		else if (typ != Ext.Typen.broken && typ != Ext.Typen.executable && typ != Ext.Typen.link && typ != Ext.Typen.none)
		{
			menu.Add(Item(di.openStandApp, path));
		}
		menu.Add(Item(di.rename, path));
		menu.Add(Item(di.showTracks, folder));
		menu.Add(Item(di.openExtDir, folder));
		return menu;
    }
    
	static internal Menu Folder(string path, string image)
	{
		Menu menu = new Menu();
		menu.Add(Item(di.play_folder, path));
		menu.Add(Item(di.enq_folder, path));
		menu.Add(Item(di.rename_folder, path));
		menu.Add(Item(di.xrename_folder, path));
		menu.Add(Item(di.showTracks, path));
		menu.Add(Item(di.openExtDir, path));
		menu.Add(Item(di.showImage, image));
		menu.Add(Item(di.openExtImg, image));
		return menu;
    }
}
