/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using MiBib;
using MiBibGtk;
using System;
using System.Collections;
using System.IO;

class MySqlQueryForm : Fenster
{
	static string title = "Query";
	
	internal static void Start(ListStore store, string[] cols, string[] headers, string[] types, string query)
	{
		Application.Init();
    	new MySqlQueryForm(store, cols, headers, types, query);
    	Application.Run();
	}
	
	ListStore store;
	ScrolledWindow scrolledWindow = new ScrolledWindow();
	string[] cols;
	string[] headers;
	string[] types;
	string query;
	TreeView treeView;
	VBox bx = new VBox();
	VBox cnt = new VBox();
	
	MySqlQueryForm(ListStore store, string[] cols, string[] headers, string[] types, string query) : base(title, Var.icon)
	{
		this.cols = cols;
		this.headers = headers;
		this.types = types;
		this.query = query;
		this.store = store;
		Init();
		FetchData();
		this.SetDefaultSize(800, 640);
		this.ShowAll();
	}
	
	void AddColumn(int number, string header, string type)
	{
		Console.WriteLine("number " + number + " type " + type);
		TreeViewColumn column;
		if (type == "bool")
		{
			CellRendererToggle rendererToggle = new CellRendererToggle();
			rendererToggle.Toggled += new ToggledHandler(ItemToggled);
			rendererToggle.Active = false;
			rendererToggle.Activatable = true;
			rendererToggle.Visible = true;
			column = new TreeViewColumn(header, rendererToggle, "active", number);
			column.Sizing = TreeViewColumnSizing.Fixed;
			column.FixedWidth = 50;
		}
		else if (type == "int" || type == "string")
		{
			CellRendererText rendererText = new CellRendererText();
			column = new TreeViewColumn(header, rendererText, "text", number);
			column.SortColumnId = number;
		}
		else return;
		treeView.AppendColumn(column);
	}
	
	void AddColumns()
	{
		//AddColumn(0, "Wahl", "bool");
		//AddColumn(0, "Nummer", "string");
		for (int i = 0; i < types.Length; i++)
		{
			AddColumn(i, headers[i], types[i]);
		}
	}
	
	void FetchData()
	{
		try
		{
			treeView = new TreeView (store);
			treeView.RulesHint = true;
			//treeView.SearchColumn = (int)ColumnNumber.Description;
			AddColumns();
			scrolledWindow.Add (treeView);
			
			query = "SELECT " + String.Join(", ", cols) + " " + query;
			bx.PackStart(new Label(query), false, false, 0);
			//Console.WriteLine("\"" + query + "\"");
			MySql3 m = new MySql3(Mvar.db, Mvar.pw, Mvar.server, Mvar.user, query);
			if (!m.open) return;
			while (m.r.Read())
			{
				Gtk.TreeIter iter = store.Append();
				for (int i = 0; i < cols.Length; i++)
				{
					if (types[i] == "bool")  store.SetValue(iter, i, (bool)m.r[cols[i]]);
					else if (types[i] == "int") store.SetValue(iter, i, Int32.Parse(m.r[i].ToString()));
					else if (types[i] == "string") store.SetValue(iter, i, (string)m.r[cols[i]]);
					else Console.WriteLine("cast missing for " + types[i]);
				}
			}
			m.Close();
		} catch (Exception e) { Console.WriteLine(e.Message); }
	}
	
	void Init()
	{
		this.Add(cnt);
		cnt.Add(bx);
		
		scrolledWindow.ShadowType = ShadowType.EtchedIn;
		scrolledWindow.SetPolicy(PolicyType.Automatic, PolicyType.Automatic);
		bx.PackStart(scrolledWindow, true, true, 0);
	}
	
	void ItemToggled (object o, ToggledArgs args)
	{
		Gtk.TreeIter iter;
		Console.WriteLine("args.Path: " + args.Path);
		if (store.GetIterFromString(out iter, args.Path))
		{
			bool val = (bool)store.GetValue(iter, 0);
			Console.WriteLine("toggled {0} with value {1}", args.Path, val);
			store.SetValue(iter, 0, !val);
		}
	}
}
