/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using MiBib;
using System;
using System.Collections;
using System.Diagnostics;

class SearchControl : VBox
{
	ArrayList types = new ArrayList();
	bool shift = false;
	Button btn;
	internal CheckButton cover;
	internal CheckButton quiz;
	ComboBox cbLimit = ComboBox.NewText();
	ComboBox cbType = ComboBox.NewText();
	internal Entry ntrSearch = new Entry();
	EventHandler ehButtonUsed;
	HBox cnt;
	int lastLimitAlbumCover = Gui.standardLastLimitAlbumCover;
	int lastLimitAlbumText = 4;
	int lastLimitTrack = 4;
	Label lblResults = new Label();
	internal RadioButton album;
	
	// Action
	RadioButton edit;
	RadioButton enq;
	RadioButton play;
	//
	
	VBox alpha = new VBox();
	VBox alphaShift = new VBox();
	VBox cntAlpha = new VBox();
	
	string[] astr = new string[]
	{
		"1234567890~",
		"qwertzuiop+",
		"asdfghjkl[]",
		"yxcvbnm,.-@"
	};
	string[] astrShift = new string[]
	{
		"!{}$%&/()=?",
		"QWERTZUIOP*",
		"ASDFGHJKL'#",
		"YXCVBNM;:_|"
	};
	internal static int[] limits = new int[]
	{
		1, 4, 9, 16, 25, 36, 49, 64, 81, 100, 400, 900
	};
	
	internal SearchControl() : base()
    {
        Init();
        this.KeyPressEvent += new KeyPressEventHandler(Key_Pressed);
    }
	
	internal ProcessStart.Actions Actions 
	{ 
		get 
		{ 
			if (play.Active) return ProcessStart.Actions.play;
			if (enq.Active) return ProcessStart.Actions.enq;
			return ProcessStart.Actions.edit;
		} 
	}
	
	internal int Limit { get { return limits[cbLimit.Active]; } }
	string Type { get { return (string)types[cbType.Active]; } }
	
	void Album_Toggled(object obj, EventArgs args)
	{
		GetLimit();
	}
	
	void Backspace(object obj, EventArgs args)
	{
		int i = ntrSearch.Text.Length;
		if (i > 0) i--;
		ntrSearch.Text = ntrSearch.Text.Substring(0, i);
	}
	
	void Button_Used(object obj, EventArgs args)
	{
		Button o = (Button)obj;
		ntrSearch.Text += o.Name;
	}
	
	void Cls(object obj, EventArgs args)
	{
		ntrSearch.Text = "";
	}
	
	void Cover_Toggled(object obj, EventArgs args)
	{
		GetLimit();
	}
	
	void CreateRow(ref VBox container, string str)
	{
		//uint col = 0;
		cnt = new HBox();
		container.PackStart(cnt, false, false, 0);
		foreach (char ch in str)
		{
			Label label = new Label(ch.ToString());
			label.HeightRequest = 14;
			label.Justify = Justification.Left;
			label.WidthRequest = 14;
			btn = new Button(label);//ch.ToString());
			btn.Clicked += ehButtonUsed;
			//btn.HeightRequest = 24;
			btn.Name = ch.ToString();
			//btn.WidthRequest = 20;
			cnt.PackStart(btn, false, false, 0);
			//tbl.Attach(btn, col, col+1, row, row+1, ao, ao, 0, 0);
			//col++;
		}
		//row++;
    }
	
	void GetLimit()
	{
		if (album.Active)
		{
			if (cover.Active) cbLimit.Active = lastLimitAlbumCover;
			else cbLimit.Active = lastLimitAlbumText;
		}
		else cbLimit.Active = lastLimitTrack;
	}
	
	void Init()
    {
    	HBox cnt;
		RadioButton rb;
		ehButtonUsed = new EventHandler(Button_Used);
		
		if (Ini.GetBool("StartWithKeyboardExpanded")) keyboardExpander.Expanded = true;
		this.PackStart(keyboardExpander);
                
		keyboardExpander.Add(cntAlpha);//, false, false, 0);
		foreach (string str in astr) CreateRow(ref alpha, str);
		foreach (string str in astrShift) CreateRow(ref alphaShift, str);
		cntAlpha.PackStart(alpha, false, false, 0);
		
		cnt = new HBox();
		btn = new Button("shift");
		btn.Clicked += new EventHandler(Shift_Toggle);
		cnt.Add(btn);
		btn = new Button(" ");
		btn.Clicked += ehButtonUsed;
		btn.Name = " ";
		cnt.Add(btn);
		btn = new Button("<-");
		btn.Clicked += new EventHandler(Backspace);
		cnt.Add(btn);
		btn = new Button("cls");
		btn.Clicked += new EventHandler(Cls);
		cnt.Add(btn);
		cntAlpha.PackEnd(cnt, false, false, 0);
		
		// play / enqueue / edit
		cnt = new HBox();
		play = new RadioButton(di.play[1]);
		play.Active = Ini.GetString("DefaultAction") == "play";
		cnt.Add(play);
		enq = new RadioButton(play, di.enq[1]);
		enq.Active = Ini.GetString("DefaultAction") == "enq";
		cnt.Add(enq);
		edit = new RadioButton(play, di.edit[1]);
		edit.Active = Ini.GetString("DefaultAction") == "edit";
		cnt.Add(edit);
		this.Add(cnt);
		// album / track
		// cover / text
		cnt = new HBox();
		
		cover = new CheckButton(di.cover[1]);
		cover.Active = true;
		cover.Toggled += new EventHandler(Cover_Toggled);
		cnt.Add(cover);
		
		quiz = new CheckButton(di.quiz[1]);//"quiz");
		quiz.Active = true;
		//quiz.Toggled += new EventHandler(Quiz_Toggled);
		cnt.Add(quiz);
		
		
		//this.Add(cnt);
		//cnt = new HBox();
		album = new RadioButton(di.album[1]);
		rb = new RadioButton(album, di.track[1]);
		rb.Active = (Ini.GetString("DefaultMode")).ToLower() == "track";
		album.Active = (Ini.GetString("DefaultMode")).ToLower() == "album";
		album.Toggled += new EventHandler(Album_Toggled);
		cnt.Add(album);
		cnt.Add(rb);
		this.Add(cnt);
		
		ntrSearch.Text = "";//tester";
		this.Add(ntrSearch);
		cnt = new HBox();
		
		btn = Buttons.GetByStock(di.search[0],
			Stock.Find, // Img.Button("kfilereplace.png"), 
			new EventHandler(Search_Clicked), null, null);
    	cnt.Add(btn);
    	
    	// btn = Buttons.Get(di.newWindow[0],
		// 	Img.Button("newWindow.png"), 
		// 	new EventHandler(NewWindow_Clicked), null, null);
    	// cnt.Add(btn);
    	
    	btn = new Button(di.rnd[1]);
    	btn.Clicked += new EventHandler(Random_Clicked);
    	cnt.Add(btn);
    	this.Add(cnt);
    	/*
    	btn = new Button("test");
    	btn.Clicked += new EventHandler(Test);
    	cnt.Add(btn);
    	cnt.Add(btn);
    	
    	btn = new Button("test2");
    	btn.Clicked += new EventHandler(Test2);
    	cnt.Add(btn);
    	cnt.Add(btn);
    	*/
    	cnt = new HBox();
    	foreach (string str in Enum.GetNames(typeof(Ext.Typen)))
    	{
    		cbType.AppendText(str);
    		types.Add(str);
    	}
    	cbType.Active = 0;
    	cnt.Add(cbType);
    	foreach (int i in limits) cbLimit.AppendText(Limit_Format(i));//.ToString());
    	cbLimit.Active = lastLimitAlbumCover;
    	cbLimit.Changed += new EventHandler(Limit_Changed);
    	cnt.Add(cbLimit);
    	cnt.Add(lblResults);
    	Results_Text(4);
    	
    	this.Add(cnt);
	}
	/*
	void Test(object o, EventArgs ea)
	{
		StockForm.Start();
		//Gui.gui.gw.view.Test();
	}
	
	void Test2(object o, EventArgs ea)
	{
		// EditForm.Start(SysInfo.IniFile(SysInfo.IniFilePart));
		//Gui.gui.gw.view.Test();
	}
	*/
	void Key_Pressed(object o, KeyPressEventArgs args)
	{
		uint k = args.Event.KeyValue;
		// Gui.gui.Message("key value: " + args.Event.KeyValue);
		// if (k == 65289) return; // TAB
		// if (k == 16777215) return; // Caps Lock
		
		if (k == 65472) // F3 //|| if (k == 65474) // F5
		{
			Search_Clicked(null, null);
		}
	}
	
	Expander keyboardExpander = new Expander("Keyboard");
	bool keyboardShow = true;
	
	internal void KeyboardToggle()
	{
		keyboardShow = !keyboardShow;
		if (keyboardShow) keyboardExpander.Show(); else keyboardExpander.Hide();
	}
	
	void Limit_Changed(object o, EventArgs args)
	{
		if (album.Active)
		{
			if (cover.Active) lastLimitAlbumCover = cbLimit.Active;
			else lastLimitAlbumText = cbLimit.Active;
		}
		else lastLimitTrack = cbLimit.Active;
	}
	
	string Limit_Format(int limit)
	{
		return String.Format("{0:D3}", limit);
	}
	
	void Random_Clicked(object o, EventArgs args)
	{
		Gui.gui.cw();
		
		int limit = Limit;
		if (limit == 0) limit = 25;
		if (album.Active) limit = 1;
		
		Rnd rnd = ntrSearch.Text == ""
			? new Rnd(album.Active, !play.Active, limit)
			: new Rnd(album.Active, !play.Active, limit, ntrSearch.Text);
		
		Gui.gui.cc();
		
		if (rnd.alPath.Count > 0)
		{
			if (!album.Active && ntrSearch.Text == "") Player.CreatePlaylistFromArrayListPath(rnd.alPath, !play.Active, 0, rnd.alPath.Count);
			else Player.CreatePlaylistFromArrayListPath(rnd.alPath, enq.Active);
			if (quiz.Active) QuizForm.Start(rnd.alPath);
		}
	}
	
	void Results_Text(int results)
	{
		lblResults.Text = " Results: " + Limit_Format(results) + " ";
	}
	
	internal void Search_Clicked(object o, EventArgs args)
	{
		ArrayList al;
		bool bRandom = false;
		if (ntrSearch.Text == "") bRandom = true;
		else if (album.Active)
		{
			if (   Type != Ext.Typen.All.ToString()
			    && Type != Ext.Typen.audio.ToString()) bRandom = true;
		}
		
		if (bRandom)
		{
			int limit = Limit;
			if (limit == 0) limit = 25;
			if (!album.Active) al = new ArrayList();
			else
			{
				//Rnd rnd = new Rnd(album.Active, limit);
				//al = rnd.alPath;
				al = new Rnd(album.Active, limit).alPath;
			}
		}
		else al = SearchStandard();
		
		Action2ViewUpdate(al);
		
		// todo: second query w/ possible results -> if (possible > max) background=red;
		Results_Text(al.Count);
		
		string confirmation = "";
		if (al.Count == 0)
		{
			Gui.gui.view.NoResults();
			confirmation = "OOPS, no results for:     \"" + ntrSearch.Text + "\"";
		}
		Gui.gui.entry.Text = confirmation;
	}
	
	void Action2ViewUpdate(ArrayList al)
	{
		Gui.rows = NumberControl.Results2NumberRows(al.Count);
		Gui.gui.Update(Gui.rows, al, "");
		
	}
	
	ArrayList SearchStandard()
	{
		return Search.Get(Limit,
		                  ntrSearch.Text,
		                  album.Active ? "album" : "sing",
		                  Type
		                 );
	}
	
	void Shift_Toggle(object o, EventArgs args)
	{
		shift = !shift;
		if (shift) 
		{
			cntAlpha.Remove(alpha);
			cntAlpha.PackStart(alphaShift, false, false, 0);
		}
		else
		{
			cntAlpha.Remove(alphaShift);
			cntAlpha.PackStart(alpha, false, false, 0);
		}
		this.ShowAll();
	}
}

















