/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using MiBib;
using MiBibGtk;
using System;
using System.Collections;
using System.IO;

class SingEditWindow : Fenster
{
	internal static void Start(string path)
	{
		Application.Init();
		new SingEditWindow(path);
		Application.Run();
	}
	
	SingEditWindow(string path) : base(path, Var.icon)
	{
		Init();
		this.path.Text = path;
		Update();
	}
	
	Box bx = new VBox();
	Entry file = new Entry();
	Entry id = new Entry();
	Entry name = new Entry();
	Entry path = new Entry();
	Entry rnd = new Entry();
	string lastFile;
	
	void Init()
	{
		this.Move(Ini.GetInt("StartPositionLeft"), Ini.GetInt("StartPositionTop"));
		this.SetDefaultSize(900, 600);
		this.Add(bx);
		
		TableInit();
		
		// ButtonBox
		Button btn;
		ButtonBox btnbx = new HButtonBox();
		
		btnbx.BorderWidth = Var.space;
		btnbx.Layout = ButtonBoxStyle.Spread;
		btnbx.Spacing = (int)Var.space;
		bx.Add(btnbx);
		
		btn = Buttons.LevelUp();
		btn.Clicked += new EventHandler(LevelUp_Clicked);
		btnbx.Add(btn);
		
		btn = new Button("_move");
		btn.Clicked += new EventHandler(Move_Clicked);
		btnbx.Add(btn);
		
		btn = new Button("_rename");
		btn.Clicked += new EventHandler(Rename_Clicked);
		btnbx.Add(btn);
		
		btn = new Button("_rename and exit");
		btn.Clicked += new EventHandler(RenameAndExit_Clicked);
		btnbx.Add(btn);
		
		this.ShowAll();
		
	}
	
	AttachOptions ao = AttachOptions.Shrink;
	Table table = new Table(6, 2, false);
	UInt32 y = 0;
	
	void TableAttach(string text, ref Entry entry, bool editable)
	{
		UInt32 x = 0;
		Label label = new Label(text);
		//label.Justify = Justification.Left;
		table.Attach(label, x, x+1, y, y+1, ao, ao, 0, 0);
		x++;
		entry.IsEditable = editable;
		table.Attach(entry, x, x+1, y, y+1);
		y++;
	}
	
	void LevelUp_Clicked(object o, EventArgs ea)
	{
		DirEditWindow.Start(System.IO.Path.GetDirectoryName(path.Text));
	}
	
	void Move_Clicked(object o, EventArgs ea)
	{
		if (file.Text != lastFile) Rename_Clicked(null, null);
		string newFolder = Dialogs.GetFolder("move to", this, false);
		if (newFolder == "") return;
		string dest = newFolder + "/" + lastFile;
		int albumId = MySql3.Id(Mvar.db, Mvar.pw, Mvar.server, Mvar.user,
		                       "album", "path", newFolder);
		Console.WriteLine("albumId " + albumId);
		string error = RenameSing(path.Text, dest);
		if (error != "") return;
		new MySql3(Mvar.db, Mvar.pw, Mvar.server, Mvar.user,
		           "UPDATE sing SET album_id=" + albumId
		                    + " WHERE path=\"" + dest + "\"");
	}
	
	void Rename_Clicked(object o, EventArgs args)
	{
		string dir = System.IO.Path.GetDirectoryName(path.Text) + "/";
		string dest = dir + file.Text;
		RenameSing(dir + lastFile, dest);
	}
	
	void RenameAndExit_Clicked(object o, EventArgs args)
	{
		Rename_Clicked(o, args);
		This_Delete(null, null);
	}
	
	string RenameSing(string source, string dest)
	{
		string error = Rename.Sing(source, dest);
		if (error != "") Message(MessageType.Error, error);
		else 
		{
			path.Text = dest;
			Update();
		}
		return error;
	}
	
	void TableInit()
	{
		table.BorderWidth = Var.space;
		table.ColumnSpacing = table.RowSpacing = Var.space;
		bx.Add(table);
		
		TableAttach(di.index[1], ref id, false);
		TableAttach(di.rnd[1], ref rnd, false);
		TableAttach("file", ref file, true);
		TableAttach("name", ref name, false);
		TableAttach("path", ref path, false);
		
	}
	
	void Update()
	{
		Sing sing = new Sing();
		sing.Create(path.Text);
		lastFile = file.Text = System.IO.Path.GetFileName(sing.path);
		id.Text = sing.id.ToString();
		name.Text = sing.name;
		path.Text = sing.path;
		rnd.Text = sing.rnd.ToString();
	}
	
}
