/* Copyright (C) 2002-NOW Mischa Lörken

This file is part of FindYourMedia (FYM), more info under <http://www.FindYourMedia.org>.

FYM is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FYM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FYM. If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using MiBib;
using MiBibGtk;
using System;
using System.Diagnostics;
using System.Collections;
using System.IO;

class XrenameWindow : Fenster
{
	internal static void Start(string path)
	{
		Application.Init();
		new XrenameWindow(path);
		Application.Run();
	}
	
	XrenameWindow(string path) : base(di.xrename[1], Var.icon)
	{
		Init();
		this.path.Text = path;
		this.Move(Ini.GetInt("StartPositionLeft"), Ini.GetInt("StartPositionTop"));
		checkButtonConfirm.Active = false;
		checkButtonFiles.Active = true;
		checkButtonFolder.Active = false;
		checkButtonSubfolder.Active = false;
		checkButtonTest.Active = false;
		Update_Clicked(null, null);
		
	}
	
	ArrayList files;
	ArrayList folder;
	AttachOptions ao = AttachOptions.Shrink;
	Box box = new VBox();
	Box cnt;
	CheckButton checkButtonConfirm = new CheckButton("confirm");
	CheckButton checkButtonFiles = new CheckButton("files");
	CheckButton checkButtonFolder = new CheckButton("folder");
	CheckButton checkButtonSubfolder = new CheckButton("subfolder");
	CheckButton checkButtonTest = new CheckButton("test");
	Entry path = new Entry();
	Entry replace = new Entry();
	Entry with = new Entry();
	ScrolledWindow scrolledWindow;
	string lastPath;
	Table table = new Table(5, 3, false);
	UInt32 y = 0;
	
	void AddEntry(ref ArrayList al, string path)
	{
		Entry o = new Entry(System.IO.Path.GetFileName(path));
		o.Name = path;
		cnt.PackStart(o, false, false, 0);
		al.Add(o);
	}
	
	void AddHeader(string title)
	{
		Label o = new Label(title);
		cnt.PackStart(o, false, false, 0);
	}
	
	void CreateContainer()
    {
    	if (scrolledWindow != null)
    	{
    		box.Remove(scrolledWindow);
    		scrolledWindow.Dispose();
    		scrolledWindow = null;
    	}
    	scrolledWindow = new ScrolledWindow();
    	box.PackStart(scrolledWindow, true, true, 0);
    }
    
    void Init()
	{
		this.Move(1, 1);
		this.SetDefaultSize(800, 734);
		//this.SetPosition(WindowPosition.Center);
		
		this.Add(box);
		
		TableInit();
		
		HBox buttonBox;
		
		buttonBox = new HBox();//Elements.HBox();//ButtonBoxH();
		//box.PackStart(buttonBox, false, false, 0);
		buttonBox.Add(checkButtonTest);
		buttonBox.Add(checkButtonConfirm);
		//table.Attach(buttonBox, 0, 1, y, y+1);
		
		//buttonBox = new HBox();//Elements.ButtonBoxH();
		//box.PackStart(buttonBox, false, false, 0);
		buttonBox.Add(checkButtonFiles);
		buttonBox.Add(checkButtonFolder);
		buttonBox.Add(checkButtonSubfolder);
		table.Attach(buttonBox, 1, 2, y, y+1);
		
		//UInt32 x = 0;
		//buttonBox = new HBox();//Elements.HBox();//ButtonBoxH();
		
		
		
		//Button button = new Button("rename");
		// button.Clicked += new EventHandler(Start_Clicked);
		
		
		// Stock.FindAndReplace
		Button button = Buttons.GetByStock("rename", Stock.Execute, new EventHandler(Start_Clicked), null, null);
		//button.Label = "rename";
		
		//buttonBox.Add(btn);
		table.Attach(button, 2, 3, y, y+1);
	}
	
	string RenameFiles()
	{
		string error = "";
		foreach (Entry entry in files)
		{
			string neu = MySql3.PathTreatment(System.IO.Path.GetDirectoryName(entry.Name)) + "/" + entry.Text;
			if (entry.Name != neu) error += Rename.Sing(entry.Name, neu);
		}
		return error;
	}
	
	string RenameFolder()
	{
		string error = "";
		foreach (Entry entry in folder)
		{
			string neu = MySql3.PathTreatment(System.IO.Path.GetDirectoryName(entry.Name)) + "/" + entry.Text;
			if (entry.Name != neu) error += Rename.Folder(entry.Name, neu);
		}
		return error;
	}
	
	string RenameX()
	{
		string error = "";
		if (replace.Text == "") return error;
		RenameX r = new RenameX(checkButtonFiles.Active, checkButtonFolder.Active, checkButtonSubfolder.Active,
		                        path.Text, replace.Text, with.Text);
		//string file = SysInfo.PathTreatment(MainClass.datpath + "/temp.txt");
		
		//error += Rename.X(
		//                  path.Text, replace.Text, with.Text);
		
		if (Ini.GetBool("x-rename_show_log")) Process.Start(r.log);
		return error;
	}
	
	void Start_Clicked(object o, EventArgs ea)
	{
		string error = "";
		error += RenameFiles();
		error += RenameFolder();
		error += RenameX();
		Update_Clicked(null, null);
		if (error != "") Error(error);
	}
	
	void TableAttach(string text, ref Entry entry, bool editable)
	{
		UInt32 x = 0;
		Label label = new Label(text);
		//label.Justify = Justification.Left;
		table.Attach(label, x, x+1, y, y+1, ao, ao, 0, 0);
		x++;
		//entry.Editable = editable;
		table.Attach(entry, x, x+2, y, y+1);
		y++;
	}
	
	void TableInit()
	{
		table.BorderWidth = Var.space;
		table.ColumnSpacing = table.RowSpacing = Var.space;
		box.PackStart(table, false, false, 0);
		
		UInt32 x = 0;
		Label label = new Label("path");
		table.Attach(label, x, x+1, y, y+1, ao, ao, 0, 0);
		x++;
		//path.Editable = true;
		path.WidthRequest = 700;
		table.Attach(path, x, x+1, y, y+1);
		x++;
		Button b = new Button("update");
		b.Clicked += new EventHandler(Update_Clicked);
		b.WidthRequest = 80;
		table.Attach(b, x, x+1, y, y+1);
		y++;
		
		TableAttach("replace", ref replace, true);
		TableAttach("with", ref with, true);
	}
	
	void Update_Clicked(object o, EventArgs args)
    {
		files = new ArrayList();
		folder = new ArrayList();
		lastPath = path.Text;
    	CreateContainer();
    	ArrayList tempFiles = InOut.DirectoryFilesSorted(lastPath);
    	ArrayList tempFolder = InOut.DirectoryFoldersSorted(false, lastPath);
    	cnt = new VBox();
    	scrolledWindow.AddWithViewport(cnt);
    	if (tempFolder.Count > 0) AddHeader("folder: " + tempFolder.Count);
    	foreach (string str in tempFolder) AddEntry(ref folder, str);
    	if (tempFiles.Count > 0) AddHeader("files: " + tempFiles.Count);
    	foreach (string str in tempFiles) AddEntry(ref files, str);
    	this.ShowAll();
    }
	
	
}
